This is the mail archive of the libc-ports@sources.redhat.com mailing list for the libc-ports project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: [PATCH] linux/alpha: convert from epoll_create2 to epoll_create1


On Tuesday, August 31, 2010 16:08:35 Mike Frysinger wrote:
> Alpha's epoll.h was missed when epoll_create2 was changed to epoll_create1.

ping x 3 ... maybe alpha is outside of what Roland wants to touch ...
-mike
From feed50101967bd7b97762d68a3b592d9798e6eb2 Mon Sep 17 00:00:00 2001
From: Mike Frysinger <vapier@gentoo.org>
Date: Tue, 31 Aug 2010 16:06:02 -0400
Subject: [PATCH 1/2] linux/alpha: convert from epoll_create2 to epoll_create1

Alpha's epoll.h was missed when epoll_create2 was changed to epoll_create1.

Signed-off-by: Mike Frysinger <vapier@gentoo.org>

2010-08-31  Mike Frysinger  <vapier@gentoo.org>

	* sysdeps/unix/sysv/linux/alpha/sys/epoll.h (epoll_create2): Delete.
	(epoll_create1): Add.
---
 sysdeps/unix/sysv/linux/alpha/sys/epoll.h |    9 +++++----
 1 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/sysdeps/unix/sysv/linux/alpha/sys/epoll.h b/sysdeps/unix/sysv/linux/alpha/sys/epoll.h
index 9f983a5..9177c31 100644
--- a/sysdeps/unix/sysv/linux/alpha/sys/epoll.h
+++ b/sysdeps/unix/sysv/linux/alpha/sys/epoll.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 2002-2006, 2007, 2008 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2008, 2010 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@ typedef __sigset_t sigset_t;
 #endif
 
 
 /* Flags to be passed to epoll_create2.  */
 enum
   {
     EPOLL_CLOEXEC = 010000000,
@@ -101,8 +101,9 @@ __BEGIN_DECLS
    returned by epoll_create() should be closed with close().  */
 extern int epoll_create (int __size) __THROW;
 
-/* Same as epoll_create but with an additional FLAGS parameter.  */
-extern int epoll_create2 (int __size, int __flags) __THROW;
+/* Same as epoll_create but with an FLAGS parameter.  The unused SIZE
+   parameter has been dropped.  */
+extern int epoll_create1 (int __flags) __THROW;
 
 
 /* Manipulate an epoll instance "epfd". Returns 0 in case of success,
@@ -31,7 +31,7 @@ typedef __sigset_t sigset_t;
 
 
-/* Flags to be passed to epoll_create2.  */
+/* Flags to be passed to epoll_create1.  */
 enum
   {
-- 
1.7.6

Attachment: signature.asc
Description: This is a digitally signed message part.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]